@@ -95,10 +95,15 @@ my $normal_opts_type = {
     thumbnail_width_max => $OPT_IS_NUMERIC, # > 0, 0 for unlimited, -1 for default
     show_caption_under_thumbnails => $OPT_IS_NUMERIC,
     show_film_effect => $OPT_IS_NUMERIC,
+    MVI_link_to_target => $OPT_IS_NUMERIC,
+    FIL_link_to_target => $OPT_IS_NUMERIC,
+    DIR_link_to_target => $OPT_IS_NUMERIC,
+    LNK_link_to_target => $OPT_IS_NUMERIC,
 # Slides
     make_no_slides => $OPT_IS_NUMERIC,
     make_slide_filename_from_filename => $OPT_IS_NUMERIC,
     make_slide_filename_from_extension => $OPT_IS_NUMERIC,
+    slide_dimensions_from_css => $OPT_IS_NUMERIC,
     slide_width_max => $OPT_IS_NUMERIC, # > 0, 0 for unlimited, -1 for default
     slide_height_max => $OPT_IS_NUMERIC, # > 0, 0 for unlimited, -1 for default
     text_slide_width => $OPT_IS_NUMERIC, # > 0, -1 for default
@@ -111,6 +116,7 @@ my $normal_opts_type = {
     link_between_last_and_first => $OPT_IS_NUMERIC,
     make_slide_title_from_caption => $OPT_IS_NUMERIC,
     show_all_exif_tags => $OPT_IS_NUMERIC,
+    slide_link_to_full_image => $OPT_IS_NUMERIC,
 # Captions
     captions_removal_line => $OPT_IS_NONEMPTY_STRING,
     make_caption_from_image_comment => $OPT_IS_STRING,
@@ -121,7 +127,7 @@ my $normal_opts_type = {
     show_size => $OPT_IS_NUMERIC,
     slide_counter_format => $OPT_IS_STRING,
 # Text
-    index_title => $OPT_IS_STRING,
+    index_title_default => $OPT_IS_STRING,
     index_link_text => $OPT_IS_NONEMPTY_STRING,
     parent_gallery_link_text => $OPT_IS_NONEMPTY_STRING,
     prev_gallery_link_text => $OPT_IS_STRING,
@@ -291,6 +297,11 @@ sub add_defaults {
 	show_caption_under_thumbnails => 0,
 # show the film effect in the index of thumbnails (--fe)
 	show_film_effect => 0,
+# link thumbnails to target instead of slide
+	MVI_link_to_target => 0,
+	FIL_link_to_target => 0,
+	DIR_link_to_target => 0,
+	LNK_link_to_target => 0,
 
 # Slides
 # make no slides, just thumbnail links to images (-s)
@@ -299,6 +310,8 @@ sub add_defaults {
 	make_slide_filename_from_filename => 0,
 # also use image extension in the slide names
 	make_slide_filename_from_extension => 0,
+# do not output dimensions for slides, let the css do it
+	slide_dimensions_from_css => 0,
 # max width of the slides (--sx)
 	slide_width_max => $slide_width_max_default,
 # max height of the slides (--sy)
@@ -320,6 +333,8 @@ sub add_defaults {
 	make_slide_title_from_caption => 0,
 # show a table of exif tags
 	show_exif_tags => [],
+# link scaled to full
+	slide_link_to_full_image => 1,
 
 # Captions
 # this line will be placed in caption generated file
@@ -340,7 +355,7 @@ sub add_defaults {
 
 # Text
 # title of the gallery (--title)
-	index_title => llgal_gettext ("index_title|Index of pictures"),
+	index_title_default => llgal_gettext ("index_title|Index of pictures"),
 # label of link to the parent gallery
 	parent_gallery_link_text => llgal_gettext ("parent_gallery_link_text|Back to parent gallery"),
 # label of link to previous gallery
@@ -379,7 +394,7 @@ sub add_defaults {
 	over_next_slide_link_text => llgal_gettext ("over_next_slide_link_text|Next slide "),
 # change kB to another unit (--asu)
 	show_size_unit => llgal_gettext ("show_size_unit|kB"),
-# format of the timestamp in captions (--ctf)
+# format of the timestamp in captions, when enabled (--ct)
 	timestamp_format_in_caption => llgal_gettext ("timestamp_format_in_caption|%y-%m-%d %H:%M:%S"),
 # credits line at the bottom of the index
 	credits_text => llgal_gettext ("credits_text|created with <a href=\"http://home.gna.org/llgal\">llgal</a>"),
@@ -478,8 +493,7 @@ Layout Options:
     --asu <s>          change file size unit (kB)
     --cc [<s>]         use image comments as captions
     --cf               use file names as captions
-    --ct               use image timestamps as captions
-    --ctf <s>          timestamp format in captions
+    --ct [<format>]    use image timestamps as captions
     --codeset <s>      change the codeset in HTML pages
     --exif [<tags>]    show exif tags on each slide
     --fe               show a film effect in the indexof thumbnails
@@ -491,6 +505,7 @@ Layout Options:
     --lt               use thumbnail preview for links in slides
     -n                 use image file names for the HTML slide files
     --nc               omit the image count from the captions
+    --nf               omit the link from slides' scaled images to full unscaled
     -p <n>             cellpadding value of thumbnail index tables (3)
     --parent-gal       add links to the parent gallery
     --php              use php extension for generated webpages
@@ -735,7 +750,11 @@ sub parse_cmdline_options {
 				else { $opts->{make_caption_from_image_comment} = $value ; }
 				},
 	'cf'		=> \$opts->{make_caption_from_filename},
-	'ct'		=> \$opts->{make_caption_from_image_timestamp},
+	'ct:s'		=> sub {
+	                        shift ; my $value = shift ;
+				$opts->{make_caption_from_image_timestamp} =  1 ;
+				if ($value ne "") { $opts->{timestamp_format_in_caption} = $value ; }
+			    },
 	'ctf=s'		=> \$opts->{timestamp_format_in_caption},
 	'codeset=s'     => \$opts->{codeset},
 	'exif:s'	=> sub {
@@ -752,6 +771,7 @@ sub parse_cmdline_options {
 	'lt'		=> sub { $opts->{prev_slide_link_preview} = 1 ; $opts->{next_slide_link_preview} = 1 ; },
 	'n'		=> \$opts->{make_slide_filename_from_filename},
 	'nc'		=> sub { $opts->{slide_counter_format} = "" ; },
+	'nf'		=> sub { $opts->{slide_link_to_full_image} = 0 ; },
 	'option=s'	=> sub { shift ; process_option $self, $opts, shift ; },
 	'P=s'		=> \@{$opts->{section_dirs}},
 	'Pall'		=> \$opts->{recursive_sections},
